@@ -83,7 +83,7 @@ int check_table(int sock, char *table) {
 void usage(void){
 		printf("dbf2msql %s\n", VERSION);
 		printf("usage:\tdbf2msql\t[-u | -l] [-h hostname] [-p primary key]\n");
-		printf("\t\t\t[-d dbase] [-t table] [-c] [-f] [-v[v]] dbf-file\n");
+		printf("\t\t\t-d dbase -t table [-c] [-f] [-v[v]] dbf-file\n");
 }
 
 void do_create(int SQLsock, char *table, dbhead *dbh) {
@@ -230,6 +230,11 @@ void do_inserts(int SQLsock, char *table, dbhead *dbh) {
 					}
 					foo=msqlEscape(fields[h].db_contents);
 					strcat(vals, foo);
+					if (fields[h].db_type == 'N') {
+						if (*foo == '\0') {
+							strcat(vals, "NULL");
+						}
+					}
 					free(foo);
 					if (fields[h].db_type != 'N') {
 						strcat(vals, "'");
@@ -250,6 +255,9 @@ void do_inserts(int SQLsock, char *table, dbhead *dbh) {
 					fprintf(stderr,
 						"Detailed report: %s\n",
 						msqlErrMsg);
+					if (verbose > 1) {
+						fprintf(stderr, "%s", query);
+					}
 				}
 			}
 			dbf_free_record(dbh, fields);
